@@ -226,7 +226,8 @@ LnSplitMatchProbability <- function (split1, split2) {
 #' Extract tip labels
 #'
 #' `TipLabels()` extracts labels from an object: for example, names of taxa in
-#' a phylogenetic tree or data matrix.
+#' a phylogenetic tree or data matrix.  `AllTipLabels()` extracts all labels,
+#' where entries of a list of trees may pertain to different taxa.
 #'
 #' @param x An object of a supported class (see Usage section above).
 #' @param single Logical specifying whether to report the labels for the first
@@ -243,6 +244,8 @@ LnSplitMatchProbability <- function (split1, split2) {
 #' data('Lobo')
 #' head(TipLabels(Lobo.phy))
 #'
+#' AllTipLabels(c(BalancedTree(4), PectinateTree(8)))
+#'
 #' @family tree properties
 #' @template MRS
 #' @export
@@ -258,12 +261,16 @@ TipLabels.phylo <- function (x, single = TRUE) x$tip.label
 
 #' @rdname TipLabels
 #' @export
-TipLabels.TreeNumber <- function (x, single = TRUE) attr(x, 'tip.label')
+TipLabels.default <- function (x, single = TRUE) attr(x, 'tip.label')
+
+#' @rdname TipLabels
+#' @export
+TipLabels.TreeNumber <- TipLabels.default
 
 #' @rdname TipLabels
 #' @family Splits operations
 #' @export
-TipLabels.Splits <- function (x, single = TRUE) attr(x, 'tip.label')
+TipLabels.Splits <- TipLabels.default
 
 #' @rdname TipLabels
 #' @export
@@ -280,6 +287,36 @@ TipLabels.list <- function (x, single = FALSE) {
   .ListLabels(x, single, TipLabels)
 }
 
+#' @rdname TipLabels
+#' @export
+AllTipLabels <- function (x) UseMethod('AllTipLabels')
+
+#' @rdname TipLabels
+#' @export
+AllTipLabels.list <- function (x) {
+  unique(unlist(lapply(x, TipLabels)))
+}
+
+#' @rdname TipLabels
+#' @export
+AllTipLabels.multiPhylo <- AllTipLabels.list
+
+#' @rdname TipLabels
+#' @export
+AllTipLabels.phylo <- function(x) TipLabels.phylo(x)
+
+#' @rdname TipLabels
+#' @export
+AllTipLabels.Splits <- function (x) TipLabels.Splits(x)
+
+#' @rdname TipLabels
+#' @export
+AllTipLabels.TreeNumber <- function (x) TipLabels.TreeNumber(x)
+
+#' @rdname TipLabels
+#' @export
+AllTipLabels.matrix <- function (x) TipLabels.matrix(x)
+
 #' @keywords internal
 .ListLabels <- function (x, single, Func) {
   if (length(x)) {
