@@ -542,10 +542,14 @@ NonDuplicateRoot <- function (parent, child, nEdge = length(parent)) {
 #' @export
 NTip <- function (phy) UseMethod('NTip')
 
+#' @rdname NTip
+#' @export
+NTip.default <- function(phy) attr(phy, 'nTip')
+
 #' @rdname NTip
 #' @family Splits operations
 #' @export
-NTip.Splits <- function (phy) attr(phy, 'nTip')
+NTip.Splits <- NTip.default
 
 #' @rdname NTip
 #' @export
@@ -623,6 +627,14 @@ NSplits.Splits <- function (x) nrow(x)
 #' @export
 NSplits.numeric <- function (x) pmax(0L, x - 3L)
 
+#' @rdname NSplits
+#' @export
+NSplits.NULL <- function (x) NULL
+
+#' @rdname NSplits
+#' @export
+NSplits.ClusterTable <- function (x) nrow(as.matrix(x)) - 3L # Root + Ingroup + All-leaves
+
 #' @rdname NSplits
 #' @importFrom ape read.tree
 #' @export
@@ -659,14 +671,6 @@ NSplits.character <- function (x) {
 #' @export
 SplitsInBinaryTree <- function (tree) UseMethod('SplitsInBinaryTree')
 
-#' @rdname SplitsInBinaryTree
-#' @export
-SplitsInBinaryTree.phylo <- function (tree) NTip(tree) - 3L
-
-#' @rdname SplitsInBinaryTree
-#' @export
-SplitsInBinaryTree.Splits <- SplitsInBinaryTree.phylo
-
 #' @rdname SplitsInBinaryTree
 #' @export
 SplitsInBinaryTree.list <- function (tree) vapply(tree, SplitsInBinaryTree, 0L)
@@ -679,6 +683,22 @@ SplitsInBinaryTree.multiPhylo <- SplitsInBinaryTree.list
 #' @export
 SplitsInBinaryTree.numeric <- function (tree) as.integer(tree) - 3L
 
+#' @rdname SplitsInBinaryTree
+#' @export
+SplitsInBinaryTree.NULL <- function(tree) NULL
+
+#' @rdname SplitsInBinaryTree
+#' @export
+SplitsInBinaryTree.default <- function(tree) NTip(tree) - 3L
+
+#' @rdname SplitsInBinaryTree
+#' @export
+SplitsInBinaryTree.Splits <- SplitsInBinaryTree.default
+
+#' @rdname SplitsInBinaryTree
+#' @export
+SplitsInBinaryTree.phylo <- SplitsInBinaryTree.default
+
 #' Is tree rooted?
 #'
 #' `TreeIsRooted()` is a fast alternative to `ape::is.rooted()`.
